@@ -15,37 +15,40 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
+#include "notificationslistener.h"
 
-#include <QtDBus/QDBusConnection>
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusArgument>
+#include <QDBusInterface>
+#include <QDBusArgument>
 #include <QtDebug>
 #include <QLoggingCategory>
 #include <QStandardPaths>
 #include <QImage>
 #include <KConfig>
 #include <KConfigGroup>
-
 #include <kiconloader.h>
 #include <kicontheme.h>
 
 #include <core/device.h>
 #include <core/kdeconnectplugin.h>
 
-#include "notificationslistener.h"
+#include <dbushelper.h>
+
 #include "sendnotificationsplugin.h"
 #include "sendnotification_debug.h"
 #include "notifyingapplication.h"
 
+//In older Qt released, qAsConst isnt available
+#include "qtcompat_p.h"
+
 NotificationsListener::NotificationsListener(KdeConnectPlugin* aPlugin)
     : QDBusAbstractAdaptor(aPlugin),
       m_plugin(aPlugin)
 {
     qRegisterMetaTypeStreamOperators<NotifyingApplication>("NotifyingApplication");
 
-    bool ret = QDBusConnection::sessionBus()
+    bool ret = DBusHelper::sessionBus()
                 .registerObject(QStringLiteral("/org/freedesktop/Notifications"),
                                 this,
                                 QDBusConnection::ExportScriptableContents);
@@ -53,7 +56,7 @@ NotificationsListener::NotificationsListener(KdeConnectPlugin* aPlugin)
         qCWarning(KDECONNECT_PLUGIN_SENDNOTIFICATION)
                 << "Error registering notifications listener for device"
                 << m_plugin->device()->name() << ":"
-                << QDBusConnection::sessionBus().lastError();
+                << DBusHelper::sessionBus().lastError();
     else
         qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION)
                 << "Registered notifications listener for device"
@@ -62,7 +65,7 @@ NotificationsListener::NotificationsListener(KdeConnectPlugin* aPlugin)
     QDBusInterface iface(QStringLiteral("org.freedesktop.DBus"), QStringLiteral("/org/freedesktop/DBus"),
                          QStringLiteral("org.freedesktop.DBus"));
     iface.call(QStringLiteral("AddMatch"),
-               "interface='org.freedesktop.Notifications',member='Notify',type='method_call',eavesdrop='true'");
+               QStringLiteral("interface='org.freedesktop.Notifications',member='Notify',type='method_call',eavesdrop='true'"));
 
     setTranslatedAppName();
     loadApplications();
@@ -76,8 +79,8 @@ NotificationsListener::~NotificationsListener()
     QDBusInterface iface(QStringLiteral("org.freedesktop.DBus"), QStringLiteral("/org/freedesktop/DBus"),
                          QStringLiteral("org.freedesktop.DBus"));
     QDBusMessage res = iface.call(QStringLiteral("RemoveMatch"),
-                                  "interface='org.freedesktop.Notifications',member='Notify',type='method_call',eavesdrop='true'");
-    QDBusConnection::sessionBus().unregisterObject(QStringLiteral("/org/freedesktop/Notifications"));
+                                  QStringLiteral("interface='org.freedesktop.Notifications',member='Notify',type='method_call',eavesdrop='true'"));
+    DBusHelper::sessionBus().unregisterObject(QStringLiteral("/org/freedesktop/Notifications"));
 }
 
 void NotificationsListener::setTranslatedAppName()
@@ -100,8 +103,9 @@ void NotificationsListener::loadApplications()
     const QVariantList list = m_plugin->config()->getList(QStringLiteral("applications"));
     for (const auto& a : list) {
         NotifyingApplication app = a.value<NotifyingApplication>();
-        if (!m_applications.contains(app.name))
+        if (!m_applications.contains(app.name)) {
             m_applications.insert(app.name, app);
+        }
     }
     //qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION) << "Loaded" << applications.size() << " applications";
 }
@@ -169,7 +173,7 @@ QSharedPointer<QIODevice> NotificationsListener::iconForIconName(const QString&
             // try falling back to hicolor theme:
             KIconTheme hicolor(QStringLiteral("hicolor"));
             if (hicolor.isValid()) {
-                iconPath = hicolor.iconPath(iconName + ".png", size, KIconLoader::MatchBest);
+                iconPath = hicolor.iconPath(iconName + QStringLiteral(".png"), size, KIconLoader::MatchBest);
                 //qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION) << "Found non-png icon in default theme trying fallback to hicolor:" << iconPath;
             }
         }
@@ -179,6 +183,7 @@ QSharedPointer<QIODevice> NotificationsListener::iconForIconName(const QString&
         return QSharedPointer<QIODevice>(new QFile(iconPath));
     return QSharedPointer<QIODevice>();
 }
+
 uint NotificationsListener::Notify(const QString& appName, uint replacesId,
                                    const QString& appIcon,
                                    const QString& summary, const QString& body,
@@ -208,8 +213,9 @@ uint NotificationsListener::Notify(const QString& appName, uint replacesId,
             list << QVariant::fromValue<NotifyingApplication>(a);
         m_plugin->config()->setList(QStringLiteral("applications"), list);
         //qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION) << "Added new application to config:" << app;
-    } else
+    } else {
         app = m_applications.value(appName);
+    }
 
     if (!app.active)
         return 0;
@@ -237,11 +243,11 @@ uint NotificationsListener::Notify(const QString& appName, uint replacesId,
         return 0;
 
     //qCDebug(KDECONNECT_PLUGIN_SENDNOTIFICATION) << "Sending notification from" << appName << ":" <<ticker << "; appIcon=" << appIcon;
-    NetworkPackage np(PACKAGE_TYPE_NOTIFICATION, {
-        {"id", QString::number(replacesId > 0 ? replacesId : ++id)},
-        {"appName", appName},
-        {"ticker", ticker},
-        {"isClearable", timeout == 0}
+    NetworkPacket np(PACKET_TYPE_NOTIFICATION, {
+        {QStringLiteral("id"), QString::number(replacesId > 0 ? replacesId : ++id)},
+        {QStringLiteral("appName"), appName},
+        {QStringLiteral("ticker"), ticker},
+        {QStringLiteral("isClearable"), timeout == 0}
     });                                   // KNotifications are persistent if
                                           // timeout == 0, for other notifications
                                           // clearability is pointless
@@ -268,7 +274,7 @@ uint NotificationsListener::Notify(const QString& appName, uint replacesId,
             np.setPayload(iconSource, iconSource->size());
     }
 
-    m_plugin->sendPackage(np);
+    m_plugin->sendPacket(np);
 
     return (replacesId > 0 ? replacesId : id);
 }
