@@ -15,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #include <QApplication>
@@ -25,13 +25,14 @@
 #include <QTextStream>
 #include <QUrl>
 #include <QDBusMessage>
-#include <QDBusConnection>
 
 #include <KAboutData>
 #include <KLocalizedString>
 
+#include <dbushelper.h>
+
 #include <interfaces/devicesmodel.h>
-#include <interfaces/devicessortproxymodel.h>
+#include <interfaces/devicespluginfilterproxymodel.h>
 #include <interfaces/dbusinterfaces.h>
 #include <interfaces/dbushelpers.h>
 #include "kdeconnect-version.h"
@@ -40,15 +41,6 @@
 /**
  * Show only devices that can be shared to
  */
-class ShareDevicesProxyModel : public DevicesSortProxyModel
-{
-public:
-    bool filterAcceptsRow(int source_row, const QModelIndex & source_parent) const override {
-        const QModelIndex idx = sourceModel()->index(source_row, 0, source_parent);
-        auto device = qobject_cast<DeviceDbusInterface*>(idx.data(DevicesModel::DeviceRole).value<QObject*>());
-        return device->supportedPlugins().contains(QStringLiteral("kdeconnect_share"));
-    }
-};
 
 int main(int argc, char** argv)
 {
@@ -58,16 +50,17 @@ int main(int argc, char** argv)
                      description,
                      QStringLiteral(KDECONNECT_VERSION_STRING),
                      description,
-                     KAboutLicense::GPL, 
+                     KAboutLicense::GPL,
                      i18n("(C) 2017 Aleix Pol Gonzalez"));
     about.addAuthor( QStringLiteral("Aleix Pol Gonzalez"), QString(), QStringLiteral("aleixpol@kde.org") );
     KAboutData::setApplicationData(about);
 
     QUrl urlToShare;
+    bool open;
     {
         QCommandLineParser parser;
         parser.addPositionalArgument(QStringLiteral("url"), i18n("URL to share"));
-        parser.addHelpOption();
+        parser.addOption(QCommandLineOption(QStringLiteral("open"), QStringLiteral("Open the file on the remote device")));
         about.setupCommandLine(&parser);
         parser.process(app);
         about.processCommandLine(&parser);
@@ -76,29 +69,50 @@ int main(int argc, char** argv)
             return 1;
         }
 
-        urlToShare = QUrl::fromUserInput(parser.positionalArguments().constFirst());
+        urlToShare = QUrl::fromUserInput(parser.positionalArguments().constFirst(), QDir::currentPath(), QUrl::AssumeLocalFile);
+        open = parser.isSet(QStringLiteral("open"));
     }
 
     DevicesModel model;
     model.setDisplayFilter(DevicesModel::Paired | DevicesModel::Reachable);
-    ShareDevicesProxyModel proxyModel;
+    DevicesPluginFilterProxyModel proxyModel;
+    proxyModel.setPluginFilter(QStringLiteral("kdeconnect_share"));
     proxyModel.setSourceModel(&model);
 
     QDialog dialog;
-    dialog.setWindowTitle(urlToShare.toDisplayString());
+
     Ui::Dialog uidialog;
     uidialog.setupUi(&dialog);
     uidialog.devicePicker->setModel(&proxyModel);
-    uidialog.urlLabel->setText(urlToShare.toDisplayString());
+
+    QString displayUrl;
+
+    if (urlToShare.scheme() == QLatin1String("tel")) {
+        displayUrl = urlToShare.toDisplayString(QUrl::RemoveScheme);
+        uidialog.label->setText(i18n("Device to call %1 with:", displayUrl));
+    } else if (urlToShare.isLocalFile() && open) {
+        displayUrl = urlToShare.toDisplayString(QUrl::PreferLocalFile);
+        uidialog.label->setText(i18n("Device to open %1 on:", displayUrl));
+    } else if (urlToShare.scheme() == QLatin1String("sms")) {
+        displayUrl = urlToShare.toDisplayString(QUrl::PreferLocalFile);
+        uidialog.label->setText(i18n("Device to send a SMS with:"));
+    } else {
+        displayUrl = urlToShare.toDisplayString(QUrl::PreferLocalFile);
+        uidialog.label->setText(i18n("Device to send %1 to:", displayUrl));
+    }
+
+    dialog.setWindowTitle(displayUrl);
+
     if (dialog.exec() == QDialog::Accepted) {
         QUrl url = urlToShare;
         const int currentDeviceIndex = uidialog.devicePicker->currentIndex();
         if(!url.isEmpty() && currentDeviceIndex >= 0) {
             const QString device = proxyModel.index(currentDeviceIndex, 0).data(DevicesModel::IdModelRole).toString();
+            const QString action = open && url.isLocalFile() ? QStringLiteral("openFile") : QStringLiteral("shareUrl");
 
-            QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), "/modules/kdeconnect/devices/"+device+"/share", QStringLiteral("org.kde.kdeconnect.device.share"), QStringLiteral("shareUrl"));
+            QDBusMessage msg = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect"), QStringLiteral("/modules/kdeconnect/devices/") + device + QStringLiteral("/share"), QStringLiteral("org.kde.kdeconnect.device.share"), action);
             msg.setArguments({ url.toString() });
-            blockOnReply(QDBusConnection::sessionBus().asyncCall(msg));
+            blockOnReply(DBusHelper::sessionBus().asyncCall(msg));
             return 0;
         } else {
             QTextStream(stderr) << (i18n("Couldn't share %1", url.toString())) << endl;
